@@ -35,17 +35,20 @@ class PluginHost(object):
 
     def __enter__(self):
         vim = self.vim
-        info('install import hook/path')
+        pass # replaces next logging statement
+        #info('install import hook/path')
         self.hook = path_hook(vim)
         sys.path_hooks.append(self.hook)
         vim.VIM_SPECIAL_PATH = '_vim_path_'
         sys.path.append(vim.VIM_SPECIAL_PATH)
-        info('redirect sys.stdout and sys.stderr')
+        pass # replaces next logging statement
+        #info('redirect sys.stdout and sys.stderr')
         self.saved_stdout = sys.stdout
         self.saved_stderr = sys.stderr
         sys.stdout = RedirectStream(lambda data: vim.out_write(data))
         sys.stderr = RedirectStream(lambda data: vim.err_write(data))
-        debug('installing plugins')
+        pass # replaces next logging statement
+        #debug('installing plugins')
         self.install_plugins()
         return self
 
@@ -55,10 +58,12 @@ class PluginHost(object):
             if hasattr(plugin, 'on_plugin_teardown'):
                 plugin.on_plugin_teardown()
         vim = self.vim
-        info('uninstall import hook/path')
+        pass # replaces next logging statement
+        #info('uninstall import hook/path')
         sys.path.remove(vim.VIM_SPECIAL_PATH)
         sys.path_hooks.remove(self.hook)
-        info('restore sys.stdout and sys.stderr')
+        pass # replaces next logging statement
+        #info('restore sys.stdout and sys.stderr')
         sys.stdout = self.saved_stdout
         sys.stderr = self.saved_stderr
 
@@ -77,19 +82,23 @@ class PluginHost(object):
                     discovered = find_module(name, [directory])
                 except:
                     err_str = format_exc(5)
-                    warn('error while searching module %s: %s', name, err_str)
+                    pass # replaces next logging statement
+                    #warn('error while searching module %s: %s', name, err_str)
                     continue
-                debug('discovered %s', name)
+                pass # replaces next logging statement
+                #debug('discovered %s', name)
                 try:
                     file, pathname, description = discovered
                     module = load_module(name, file, pathname, description)
                     for name, value in inspect.getmembers(module, inspect.isclass):
                         if name.startswith('Nvim'):
                             self.discovered_plugins.append(value)
-                    debug('loaded %s', name)
+                    pass # replaces next logging statement
+                    #debug('loaded %s', name)
                 except:
                     err_str = format_exc(5)
-                    warn('error while loading module %s: %s', name, err_str)
+                    pass # replaces next logging statement
+                    #warn('error while loading module %s: %s', name, err_str)
                     continue
                 finally:
                     file.close()
@@ -99,22 +108,26 @@ class PluginHost(object):
         vim = self.vim
         for plugin_class in self.discovered_plugins:
             cls_name = plugin_class.__name__
-            debug('inspecting class %s', plugin_class.__name__)
+            pass # replaces next logging statement
+            #debug('inspecting class %s', plugin_class.__name__)
             try:
                 plugin = plugin_class(self.vim)
             except:
-                warn('constructor for %s failed. it must accept one argument',
-                     cls_name)
+                pass # replaces next logging statement
+                #warn('constructor for %s failed. it must accept one argument',
+                     #cls_name)
                 continue
             methods = inspect.getmembers(plugin, inspect.ismethod)
-            debug('registering event handlers for %s', plugin_class.__name__)
+            pass # replaces next logging statement
+            #debug('registering event handlers for %s', plugin_class.__name__)
             for name, method in methods:
                 assert method.im_self == plugin
                 if not name.startswith('on_'):
                     continue
                 # event handler
                 event_name = name[3:]
-                debug('registering %s event handler', event_name)
+                pass # replaces next logging statement
+                #debug('registering %s event handler', event_name)
                 if event_name not in self.event_handlers:
                     self.event_handlers[event_name] = [method]
                 else:
@@ -124,17 +137,20 @@ class PluginHost(object):
             if hasattr(plugin, 'provides') and plugin.provides:
                 for provider_method_name in plugin.provides:
                     for name, method in methods:
-                        debug('checking %s', name)
+                        pass # replaces next logging statement
+                        #debug('checking %s', name)
                         if name == provider_method_name:
                             self.method_handlers[name] = \
                                 method.__get__(plugin, plugin_class)
                             try:
                                 vim.register_provider(provider_method_name)
-                                debug('registered %s as a %s provider',
-                                      plugin_class.__name__,
-                                      provider_method_name)
+                                pass # replaces next logging statement
+                                #debug('registered %s as a %s provider',
+                                      #plugin_class.__name__,
+                                      #provider_method_name)
                             except vim.error as e:
-                                warn('error while registering provider: %s', e)
+                                pass # replaces next logging statement
+                                #warn('error while registering provider: %s', e)
                             break
             self.installed_plugins.append(plugin)
 
@@ -143,31 +159,37 @@ class PluginHost(object):
         handler = self.method_handlers.get(name, None)
         if not handler:
             msg = 'no method handlers registered for %s' % name
-            debug(msg)
+            pass # replaces next logging statement
+            #debug(msg)
             raise Exception(msg)
 
-        debug("running method handler for '%s %s'", name, args)
+        pass # replaces next logging statement
+        #debug("running method handler for '%s %s'", name, args)
         if args:
             rv = handler(args)
         else:
             rv = handler()
-        debug("method handler for '%s %s' returns: %s", name, args, rv)
+        pass # replaces next logging statement
+        #debug("method handler for '%s %s' returns: %s", name, args, rv)
         return rv
 
 
     def on_notification(self, name, args):
         handlers = self.event_handlers.get(name, None)
         if not handlers:
-            debug("no event handlers registered for %s", name)
+            pass # replaces next logging statement
+            #debug("no event handlers registered for %s", name)
             return
 
-        debug('running event handlers for %s', name)
+        pass # replaces next logging statement
+        #debug('running event handlers for %s', name)
         for handler in handlers:
             handler(args)
 
 
     def on_error(self, err):
-        warn('exiting due to error: %s', err)
+        pass # replaces next logging statement
+        #warn('exiting due to error: %s', err)
         self.vim.loop_stop()
 
 
